- formula
An object of class "formula": a symbolic description of the model. The terms should correspond to the column names of the argument start.d.
- start.d
For aceglm, an n by k matrix, with column names used by the argument formula, specifying the initial design for the ACE algorithm.
For paceglm, a list with each element being an n by k matrix, with column names used by the argument formula, specifying the initial design for each repetition of the ACE algorithm.
- family
A description of the error distribution and link function to be used in the model. This can be a character string naming a family function, a family function or the result of a call to a family function. (See family for details of family functions.)
- prior
An argument specifying the prior distribution.
For method = "MC", a function with one argument: B; a scalar integer. This function should return a B by p matrix, with p the number of model parameters, containing a random sample from the prior distribution of the parameters. The value of p should correspond to the number of terms specified by the formula argument.
For method = "quadrature", a list specifying a normal or uniform prior for the model parameters. For a normal prior distribution, the list should have named entries mu and sigma2 specifying the prior mean and variance-covariance matrix. The prior mean may be specified as a scalar, which will then be replicated to form an vector of common prior means, or a vector of length p. The prior variance-covariance matrix may be specified as either a scalar common variance or a vector of length p of variances (for independent prior distributions) or as a p by p matrix. For a uniform prior distribution, the list should have a named entry support, a 2 by p matrix with each column giving the lower and upper limits of the support of the independent continuous uniform distribution for the corresponding parameter.
- B
An optional argument for controlling the approximation to the expected utility. It should be a vector of length two.
For method = "MC", it specifies the size of the Monte Carlo samples, generated from the joint distribution of unknown quantities. The first sample size, B[1], gives the sample size to use in the comparison procedures, and the second sample size, B[2], gives the sample size to use for the evaluations of Monte Carlo integration that are used to fit the Gaussian process emulator. If left unspecified, the default value is c(20000,1000).
For method = "quadrature", it specifies the tuning parameters (numbers of radial abscissas and random rotations) for the implemented quadrature method; see Details for more information. If left unspecified, the default value is c(2, 8).
- criterion
An optional character argument specifying the utility function. There are currently seven utility functions implemented as follows:
pseudo-Bayesian D-optimality (criterion = "D");
pseudo-Bayesian A-optimality (criterion = "A");
pseudo-Bayesian E-optimality (criterion = "E").
Shannon information gain with Monte Carlo (MC) approximation to marginal likelihood (criterion = "SIG");
Shannon information gain with normal-based Laplace approximation to marginal likelihood (criterion = "SIG-Norm");
negative squared error loss with importance sampling approximation to posterior mean (criterion = "NSEL");
negative squared error loss with normal-based approximation to posterior mean (criterion = "NSEL-Norm");
If left unspecified, the default is "D" denoting pseudo-Bayesian D-optimality. See Details for more information.
- method
An optional character argument specifying the method of approximating the expected utility function. Current choices are method = "quadrature" for a deterministic quadrature approximation and method = "MC" for a stochastic Monte Carlo approximation. The first of these choices is only available when the argument criterion = "A", "D" or "E". The second choice is available for all possible values of the argument criterion. If left unspecified, the argument defaults to "quadrature" for criterion = "A", "D" or "E" and to "MC" otherwise. See Details for more information.
- Q
An integer specifying the number of evaluations of the approximate expected utility that are used to fit the Gaussian process emulator. The default value is 20.
- N1
An integer specifying the number of iterations of Phase I of the ACE algorithm (the coordinate exchange phase).
The default value is 20.
- N2
An integer specifying the number of iterations of Phase II of the ACE algorithm (the point exchange phase).
The default value is 100.
- lower
An argument specifying the design space. This argument can either be a scalar or a matrix of the same dimension as the argument start.d which specifies the lower limits of all coordinates of the design space. The default value is -1.
- upper
An argument specifying the design space. This argument can either be a scalar or a matrix of the same dimension as the argument start.d which specifies the upper limits of all coordinates of the design space. The default value is 1.
- progress
A logical argument indicating whether the iteration number and other information detailing the progress of the algorithm should be printed. The default value is FALSE.
- limits
An argument specifying the grid over which to maximise the Gaussian process emulator for the expected utility function. It should be a function with three arguments: i, j and d which generates a one-dimensional grid for the ijth coordinate of the design when the current design is d. The default value is NULL which generates values uniformly on the interval (lower[i,j],upper[i,j]) or (lower,upper) depending on whether the arguments lower and upper are matrices or scalars, respectively.
- mc.cores
The number of cores to use, i.e. at most how many child processes will be run simultaneously. Must be at least one (the default), and parallelisation requires at least two cores. See mclapply for more information and warnings for mc.cores > 1.
- n.assess
If method = "MC", the approximate expected utility for the design from each repetition of the ACE algorithm will be calculated n.assess times. The terminal design returned will be the design with the largest mean approximate expected utility calculated over the n.assess approximations.